@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: actions.cpp 2965 2010-04-13 16:18:29Z lasconic $
+//  $Id: actions.cpp 3975 2011-02-02 12:36:44Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -28,7 +28,7 @@
 
 Shortcut MuseScore::sc[] = {
       Shortcut(
-         STATE_NORMAL | STATE_NOTE_ENTRY | STATE_EDIT | STATE_PLAY,
+         STATE_INIT | STATE_DISABLED | STATE_NORMAL | STATE_NOTE_ENTRY | STATE_EDIT | STATE_PLAY | STATE_SEARCH,
          "local-help",
          QT_TRANSLATE_NOOP("action","Local handbook"),            // Appears in Edit > Preferences > Shortcuts
          Qt::Key_F1,
@@ -521,7 +521,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY,
          "rest",
          QT_TRANSLATE_NOOP("action","Enter rest"),
-         Qt::Key_Space,
+         Qt::Key_0,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","Rest"),
          QT_TRANSLATE_NOOP("action","Enter rest"),
@@ -1623,7 +1623,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY | STATE_PLAY,
          "play",
          QT_TRANSLATE_NOOP("action","Player play"),
-         0, // Qt::CTRL + Qt::Key_Space, (do not use: used for multibyte (asian) languages)
+         Qt::Key_Space,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","Play"),
          QT_TRANSLATE_NOOP("action","Start or stop playback"),
@@ -2103,7 +2103,7 @@ Shortcut MuseScore::sc[] = {
          QT_TRANSLATE_NOOP("action","follow song"),
          0,
          Qt::WindowShortcut,
-         QT_TRANSLATE_NOOP("action","F"),
+         QT_TRANSLATE_NOOP("action","Follow Song"),
          QT_TRANSLATE_NOOP("action","Follow Song")
          ),
       Shortcut(
