@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: barline.cpp 3274 2010-07-12 08:58:45Z wschweer $
+//  $Id: barline.cpp 3808 2010-12-24 10:11:39Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -231,7 +231,7 @@ void BarLine::draw(QPainter& p) const
                   double x1   =  dotw + d1 + lw * .5;                                // thin bar
                   double x2   =  dotw + d1 + lw + d1 + lw2 * .5;                     // thick bar
                   double x3   =  dotw + d1 + lw + d1 + lw2 + d1 + lw * .5;           // thin bar
-                  double x4   =  dotw + d1 + lw + d1 + lw2 + d1 + lw + dotw * .5;    // dots
+                  double x4   =  dotw + d1 + lw + d1 + lw2 + d1 + lw + d1;           // dot position
 
                   if (parent() == 0) {    // for use in palette
                         symbols[dotSym].draw(p, mags, .0, 1.5 * ld);
@@ -469,7 +469,7 @@ void BarLine::layout()
                   dw = point(w);
                   break;
             case  END_START_REPEAT:
-                  w  += score()->styleS(ST_endBarWidth) + 3 * score()->styleS(ST_endBarDistance);
+                  w  += score()->styleS(ST_barWidth) + score()->styleS(ST_endBarWidth) + 4 * score()->styleS(ST_endBarDistance);
                   dw = point(w) + 2 * symbols[dotSym].width(magS());
                   break;
             case BROKEN_BAR:
