@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: beam.cpp 2971 2010-04-16 10:37:09Z wschweer $
+//  $Id: beam.cpp 3500 2010-09-23 15:23:36Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -461,7 +461,7 @@ void Beam::layout1()
 
 void Beam::layout()
       {
-      if (_elements.isEmpty()) {
+      if (_elements.isEmpty() || !c1 || !c2) {
             printf("Beam::layout: no notes\n");
             return;
             }
@@ -786,7 +786,7 @@ void Beam::layout()
 
             double x2 = npos.x();
             double y1 = npos.y();
-            double y  = _up ? qMin(p1dy, _p1[idx].y()) : qMax(p1dy, _p1[idx].y());
+            double y  = _up ? qMin(qreal(p1dy), _p1[idx].y()) : qMax(p1dy, _p1[idx].y());
             double y2 = y + (x2 - x1) * slope + cp.y();
 
             double stemLen = _up ? (y1 - y2) : (y2 - y1);
