@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chord.cpp 3461 2010-09-14 10:34:35Z lasconic $
+//  $Id: chord.cpp 3952 2011-01-26 11:33:22Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -206,17 +206,14 @@ void StemSlash::draw(QPainter& p) const
       }
 
 //---------------------------------------------------------
-//   bbox
+//   setLine
 //---------------------------------------------------------
 
-QRectF StemSlash::bbox() const
+void StemSlash::setLine(const QLineF& l)
       {
+      line = l;
       double w = point(score()->styleS(ST_stemWidth)) * .5;
-      QRectF r(line.p1().x(), line.p2().y(),
-         line.p2().x()-line.p1().x(),
-         line.p1().y()-line.p2().y()
-         );
-      return r.adjusted(-w, -w, 2.0 * w, 2.0 * w);
+      _bbox = QRectF(line.p1(), line.p2()).normalized().adjusted(-w, w, 2.0*w, 2.0*w);
       }
 
 //---------------------------------------------------------
@@ -514,7 +511,11 @@ void Chord::addLedgerLine(double x, int staffIdx, int line, int lr)
       h->setTrack(staffIdx * VOICES);
       h->setVisible(!staff()->invisible());
 
-      Spatium len(h->len());
+      // ledger lines extend less than half a space on each side
+	 	  // of the notehead:
+	 	  //
+	 	  double ll = _notes[0]->headWidth() + _spatium * .60;
+	 	  Spatium len(ll / _spatium);
 
       if (_noteType != NOTE_NORMAL)
             len *= score()->style(ST_graceNoteMag).toDouble();
@@ -978,7 +979,6 @@ LedgerLine::LedgerLine(Score* s)
    : Line(s, false)
       {
       setSelectable(false);
-      setLen(Spatium(2.0));
       }
 
 //---------------------------------------------------------
@@ -1113,33 +1113,47 @@ void Chord::layoutStem()
             Spatium shortest(score()->styleS(ST_shortestStem));
 
             double normalStemLen = small() ? 2.5 : 3.5;
-            if (_noteType != NOTE_NORMAL)
-                  normalStemLen *= score()->style(ST_graceNoteMag).toDouble();
+            switch(hookIdx) {
+                  case 3: normalStemLen += small() ? .5  : 0.75; break; //32nd notes
+                  case 4: normalStemLen += small() ? 1.0 : 1.5;  break; //64th notes
+                  //case 5: normalStemLen += small() ? 1.5 : 2.25; break; //128th notes not yet supported in MuseScore
+                  }
 
-            if (up()) {
-                  double dy  = dl + downnote->stemYoff(true);
-                  double sel = ul - normalStemLen;
-
-                  if (shortenStem && (sel < 0.0) && (hookIdx == 0 || !downnote->mirror()))
-                        sel -= sel  * progression.val();
-                  if (sel > 2.0)
-                        sel = 2.0;
-                  stemLen = Spatium(sel - dy);
-                  if (-stemLen < shortest)
-                        stemLen = -shortest;
+            if (_noteType != NOTE_NORMAL) {
+                  // grace notes stems are not subject to normal
+                  // stem rules
+                  stemLen = Spatium(qAbs(ul - dl));
+                  stemLen += Spatium(normalStemLen * score()->style(ST_graceNoteMag).toDouble());
+                  if (up())
+                        stemLen *= -1;
                   }
             else {
-                  double uy  = ul + upnote->stemYoff(false);
-                  double sel = dl + normalStemLen;
-
-                  if (shortenStem && (sel > 4.0) && (hookIdx == 0 || downnote->mirror()))
-                        sel -= (sel - 4.0)  * progression.val();
-                  if (sel < 2.0)
-                        sel = 2.0;
-                  stemLen    = Spatium(sel - uy);
-                  if (stemLen < shortest)
-                        stemLen = shortest;
+                  if (up()) {
+                        double dy  = dl + downnote->stemYoff(true);
+                        double sel = ul - normalStemLen;
+      
+                        if (shortenStem && (sel < 0.0) && (hookIdx == 0 || !downnote->mirror()))
+                              sel -= sel  * progression.val();
+                        if (sel > 2.0)
+                              sel = 2.0;
+                        stemLen = Spatium(sel - dy);
+                        if (-stemLen < shortest)
+                              stemLen = -shortest;
+                        }
+                  else {
+                        double uy  = ul + upnote->stemYoff(false);
+                        double sel = dl + normalStemLen;
+      
+                        if (shortenStem && (sel > 4.0) && (hookIdx == 0 || downnote->mirror()))
+                              sel -= (sel - 4.0)  * progression.val();
+                        if (sel < 2.0)
+                              sel = 2.0;
+                        stemLen    = Spatium(sel - uy);
+                        if (stemLen < shortest)
+                              stemLen = shortest;
+                        }
                   }
+                  
 
             QPointF npos(stemPos(_up, false));
 
@@ -1148,13 +1162,16 @@ void Chord::layoutStem()
 
             if (_stemSlash) {
                   // TODO: does not work for chords
-                  double x = _stem->pos().x();
-                  double y = _stem->pos().y();
-                  double l = point(stemLen) * .5;
-                  y += l;
-                  double h2 = l * .5;
+                  double l = spatium() * 1.0;
+                  double x = _stem->pos().x() + l * .1;
+                  double y = _stem->pos().y() + point(stemLen);
+                  if (up())
+                        y += l * 1.2;
+                  else
+                        y -= l * 1.2;
+                  double h2 = l * (up() ? .4 : -.4);
                   double w  = upnote->headWidth() * .7;
-                  _stemSlash->setLine(QLineF(QPointF(x + w, y + h2), QPointF(x - w, y - h2)));
+                  _stemSlash->setLine(QLineF(QPointF(x + w, y - h2), QPointF(x - w, y + h2)));
                   }
 
             if (hookIdx) {
@@ -1188,51 +1205,52 @@ void Chord::layoutStem()
 void Chord::layout2()
       {
       double _spatium = spatium();
-      foreach(LedgerLine* h, _ledgerLines) {
-            //
-            // Experimental:
-            //    look for colliding ledger lines
-            //
 
-            double y = h->y();
-            double x = h->x();
-            Spatium len(h->len());
+      //
+      // Experimental:
+      //    look for colliding ledger lines
+      //
+
+      const double minDist = _spatium * .17;
+
+      Segment* s = segment()->prev();
+      if (s && (s->subtype() & (SegChordRest | SegGrace))) {
+            int strack = staffIdx() * VOICES;
+            int etrack = strack + VOICES;
+            foreach (LedgerLine* h, _ledgerLines) {
+                  Spatium len(h->len());
+                  double y   = h->y();
+                  double x   = h->x();
+                  bool found = false;
+                  double cx  = h->canvasPos().x();
 
-            double minDist = _spatium * .2;
-            bool found = false;
-            double cx  = x + canvasPos().x();
-            Segment* s = segment()->prev();
-            if (s && s->subtype() == SegChordRest) {
-                  int strack = staffIdx() * VOICES;
-                  int etrack = strack + VOICES;
                   for (int track = strack; track < etrack; ++track) {
-                        if (s->element(track)) {
-                              Element* e = s->element(track);
-                              if (e->type() == CHORD) {
-                                    Chord* ch = static_cast<Chord*>(e);
-                                    foreach(LedgerLine* ll, *ch->ledgerLines()) {
-                                          if (ll->y() == y) {
-                                                double d = cx - (ll->canvasPos().x() + ll->len().val()*_spatium) - minDist;
-                                                if (d < 0.0) {
-                                                      double shorten = -d;
-                                                      x   += shorten;
-                                                      len -= Spatium(shorten / _spatium);
-                                                      ll->setLen(ll->len() - Spatium(shorten / _spatium));
-                                                      }
-                                                found = true;
-                                                break;
-                                                }
-                                          }
+                        Element* e = s->element(track);
+                        if (!e || e->type() != CHORD)
+                              continue;
+                        foreach (LedgerLine* ll, *static_cast<Chord*>(e)->ledgerLines()) {
+                              if (ll->y() != y)
+                                    continue;
+
+                              double d = cx - ll->canvasPos().x() - (ll->len().val() * _spatium);
+                              if (d < minDist) {
+                                    //
+                                    // the ledger lines overlap
+                                    //
+                                    double shorten = (minDist - d) * .5;
+                                    x   += shorten;
+                                    len -= Spatium(shorten / _spatium);
+                                    ll->setLen(ll->len() - Spatium(shorten / _spatium));
+                                    h->setLen(len);
+                                    h->setPos(x, y);
                                     }
+                              found = true;
+                              break;
                               }
                         if (found)
                               break;
                         }
                   }
-            if (found) {
-                  h->setLen(len);
-                  h->setPos(x, y);
-                  }
             }
       }
 
@@ -1292,8 +1310,10 @@ void Chord::layout()
                   _dotPosX = xx;
 
             Accidental* accidental = note->accidental();
-            if (accidental)
-                  x = (accidental->x() + accidental->bbox().x()) * mag();
+            if (accidental){
+                  x = (accidental->x() + accidental->bbox().x()) * mag()+ note->x();
+                  }
+            
             if (x < lx)
                   lx = x;
             }
