@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: edit.cpp 3482 2010-09-21 07:10:03Z lasconic $
+//  $Id: edit.cpp 3964 2011-02-01 08:50:00Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -681,8 +681,9 @@ void Score::cmdAddTie()
       Chord* chord  = note->chord();
       if (noteEntryMode()) {
             if (_is.cr() == 0) {
-                  printf("cmdAddTie: no pos\n");
-                  return;
+                  if(debugMode)
+                        printf("cmdAddTie: no pos\n");
+                  expandVoice();
                   }
             startCmd();
             Note* n = addPitch(note->pitch(), false);
@@ -1422,8 +1423,14 @@ void ScoreView::cmdTuplet(int n)
       else {
             QSet<ChordRest*> set;
             foreach(Element* e, _score->selection().elements()) {
-                  if (e->type() == NOTE)
-                        e = static_cast<Note*>(e)->chord();
+                  if (e->type() == NOTE) {
+                        Note* note = static_cast<Note*>(e); 
+                        if(note->noteType() != NOTE_NORMAL) { //no tuplet on grace notes
+                              _score->endCmd();
+                              return; 
+                              }
+                        e = note->chord();
+                        }
                   if (e->isChordRest()) {
                         ChordRest* cr = static_cast<ChordRest*>(e);
                         if(!set.contains(cr)) {
@@ -1681,15 +1688,14 @@ void Score::cmdExchangeVoice(int s, int d)
       int t2 = selection().tickEnd();
 
       Measure* m1 = tick2measure(t1);
-      Measure* m2 = tick2measure(t2);
-printf("exchange voice %d %d, tick %d-%d, measure %p-%p\n", s, d, t1, t2, m1, m2);
+      Measure* m2 = tick2measure(t2);      
+      if (t2 > m2->tick())
+            m2 = 0;
+      
       for (;;) {
             undoExchangeVoice(m1, s, d, selection().staffStart(), selection().staffEnd());
-            MeasureBase* mb = m1->next();
-            while (mb && mb->type() != MEASURE)
-                  mb = mb->next();
-            m1 = static_cast<Measure*>(mb);
-            if (m1 == 0 || m1 == m2)
+            m1 = m1->nextMeasure();
+            if ((m1 == 0) || (m2 && (m1->tick() == m2->tick())))
                   break;
             }
       }
@@ -1700,13 +1706,16 @@ printf("exchange voice %d %d, tick %d-%d, measure %p-%p\n", s, d, t1, t2, m1, m2
 
 void Score::cmdEnterRest(const Duration& d)
       {
+      if (_is.track == -1) {
+            printf("cmdEnterRest: track -1\n");
+            return;
+            }
       startCmd();
       expandVoice();
       if (_is.cr() == 0) {
             printf("cannot enter rest here\n");
             return;
             }
-
       int track = _is.track;
       Segment* seg  = setNoteRest(_is.cr(), track, -1, d.fraction(), 0, AUTO);
       ChordRest* cr = static_cast<ChordRest*>(seg->element(track));
