@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: element.cpp 3274 2010-07-12 08:58:45Z wschweer $
+//  $Id: element.cpp 3892 2011-01-15 15:47:03Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -222,7 +222,8 @@ Element::~Element()
                   if (e == this) {
 //                        if (debugMode)
                               printf("======~Element: %p still in selection!\n", this);
-//                        abort();
+                        if (debugMode)
+                              abort();
                         score()->deselect(this);
                         }
                   }
@@ -884,15 +885,21 @@ void Line::layout()
 
 void Line::draw(QPainter& p) const
       {
-      double sp = spatium();
+      p.save();
+
       QPen pen(p.pen());
+      pen.setCapStyle(Qt::FlatCap);
+      double sp = spatium();
       pen.setWidthF(_width.val() * sp);
       p.setPen(pen);
-      double l  = _len.val() * sp;
+
+      double l = _len.val() * sp;
       if (vertical)
             p.drawLine(QLineF(0.0, 0.0, 0.0, l));
       else
             p.drawLine(QLineF(0.0, 0.0, l, 0.0));
+
+      p.restore();
       }
 
 //---------------------------------------------------------
@@ -1423,3 +1430,11 @@ void collectElements(void* data, Element* e)
       el->append(e);
       }
 
+//---------------------------------------------------------
+//   elementLessThan
+//---------------------------------------------------------
+
+bool elementLessThan(const Element* const e1, const Element* const e2)
+      {
+      return e1->type() > e2->type();
+      }
