@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: file.cpp 3269 2010-07-09 20:20:39Z lasconic $
+//  $Id: file.cpp 3957 2011-01-29 13:40:15Z wschweer $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -179,17 +179,16 @@ void MuseScore::loadFile()
          this,
          tr("MuseScore: Load Score"),
          lastOpenPath,
-         tr("All Supported Files (*.mscz *.mscx *.msc *.xml *.mxl *.mid *.midi *.kar *.md *.mgu *.MGU *.sgu *.SGU *.cap *.ove);;"
-            "MuseScore Files (*.mscz *.mscx *.msc);;"
-            "MusicXML Files (*.xml *.mxl);;"
-            "MIDI Files (*.mid *.midi *.kar);;"
-            "Muse Data Files (*.md);;"
-            "Capella Files (*.cap);;"
-//            "LilyPond Files <experimental> (*.ly);;"
-            "BB Files <experimental> (*.mgu *.MGU *.sgu *.SGU);;"
-        	  "Overture Files <experimental> (*.ove);;"
-            "All Files (*)"
-            )
+         tr("All Supported Files (*.mscz *.mscx *.msc *.xml *.mxl *.mid *.midi *.kar *.md *.mgu *.MGU *.sgu *.SGU *.cap *.ove *.bww);;")+
+         tr("MuseScore Files (*.mscz *.mscx *.msc);;")+
+         tr("MusicXML Files (*.xml *.mxl);;")+
+         tr("MIDI Files (*.mid *.midi *.kar);;")+
+         tr("Muse Data Files (*.md);;")+
+         tr("Capella Files (*.cap);;")+
+         tr("Bagpipe Music Writer Files (*.bww);;")+
+         tr("BB Files <experimental> (*.mgu *.MGU *.sgu *.SGU);;")+
+         tr("Overture Files <experimental> (*.ove);;")+
+         tr("All Files (*)")
          );
       if (fn.isEmpty())
             return;
@@ -413,6 +412,10 @@ bool Score::saveAs(bool saveCopy)
       QString saveDirectory = saveCopy ?
             mscore->lastSaveCopyDirectory : mscore->lastSaveDirectory;
 
+      if (saveDirectory.isEmpty()) {
+            saveDirectory = preferences.workingDirectory;
+            }
+
       QString selectedFilter;
       QString fn = QFileDialog::getSaveFileName(
                0,
@@ -580,6 +583,8 @@ void MuseScore::newFile()
       int pickupTimesigZ, pickupTimesigN;
       newWizard->timesig(&timesigZ, &timesigN);
       bool pickupMeasure = newWizard->pickupMeasure(&pickupTimesigZ, &pickupTimesigN);
+      if (pickupMeasure)
+	 	       measures += 1;
       KeySigEvent ks = newWizard->keysig();
 
       Score* score = new Score(defaultStyle);
@@ -1243,7 +1248,7 @@ bool Score::read(QDomElement e)
 //                                                   v1, v2, v3, rv1, rv2, rv3);
 
                                                 int currentVersion = v1 * 10000 + v2 * 100 + v3;
-                                                int readVersion = rv1 * 10000 + rv2 * 100 + v3;
+                                                int readVersion    = rv1 * 10000 + rv2 * 100 + rv3;
                                                 if (readVersion > currentVersion) {
                                                       printf("read future version\n");
                                                       }
@@ -1569,8 +1574,8 @@ void Score::print(QPrinter* printer)
             const QList<Page*> pl = pages();
             int pages = pl.size();
 
-            int fromPage = printer->fromPage() - 1;
-            int toPage   = printer->toPage() - 1;
+            int fromPage = printer->fromPage() - 1 - pageFormat()->_pageOffset;
+            int toPage   = printer->toPage() - 1 - pageFormat()->_pageOffset;
             if (fromPage < 0)
                   fromPage = 0;
             if ((toPage < 0) || (toPage >= pages))
@@ -1585,6 +1590,7 @@ void Score::print(QPrinter* printer)
 
                   QRectF fr = page->abbox();
                   QList<const Element*> ell = items(fr);
+                  qStableSort(ell.begin(), ell.end(), elementLessThan);
 
                   foreach(const Element* e, ell) {
                         e->itemDiscovered = 0;
