@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: importmidi.cpp 3271 2010-07-10 17:51:30Z lasconic $
+//  $Id: importmidi.cpp 3740 2010-12-04 14:43:06Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -642,6 +642,8 @@ static QString instrName(int type, int hbank, int lbank, int program)
 
 void Score::addLyrics(int tick, int staffIdx, const QString& txt)
       {
+      if(txt.trimmed().isEmpty())
+            return;  
       Measure* measure = tick2measure(tick);
       Segment* seg = measure->findSegment(SegChordRest, tick);
       if (seg == 0) {
