@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: instrdialog.cpp 3391 2010-08-15 12:03:28Z lasconic $
+//  $Id: instrdialog.cpp 3798 2010-12-23 11:01:00Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -878,13 +878,6 @@ void Score::cmdRemoveStaff(int staffIdx)
                               undoRemoveElement(e);
                               }
                         break;
-                  case SLUR:
-                        {
-                        Slur* slur = static_cast<Slur*>(e);
-                        if ((slur->staffIdx() == staffIdx) || (slur->staffIdx2() == staffIdx))
-                              undoRemoveElement(slur);
-                        }
-                        break;
                   default:
                         break;
                   }
