@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: layout.cpp 3276 2010-07-12 09:29:28Z lasconic $
+//  $Id: layout.cpp 3908 2011-01-17 11:44:39Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -413,7 +413,7 @@ void Score::layoutStage1()
                                     foreach(const Element* el, _gel) {
                                           if (el->type() == VOLTA) {
                                                 const Volta* volta = static_cast<const Volta*>(el);
-                                                if (m->tick() >= volta->tick() && m->tick() <= volta->tick2()) {
+                                                if (m->tick() == volta->tick2()) {
                                                       m->setBreakMMRest(true);
                                                       break;
                                                       }
@@ -1306,7 +1306,19 @@ QList<System*> Score::layoutSystemRow(qreal x, qreal y, qreal rowWidth,
                               Staff* staff = _staves[staffIdx];
                               KeySigEvent key1 = staff->key(tick - 1);
                               KeySigEvent key2 = staff->key(tick);
-                              if (key1 != key2) {
+
+                              // locate a key sig. in next measure and, if found, check it has court. sig turned off
+                              Measure * nm = m->nextMeasure();
+                              Segment * pKeySigSegm;
+                              Element * pKeySigElem;
+                              bool bShowCourtesySig = true;	// assume this key change has court. sig turned on
+                              if(nm && (pKeySigSegm = nm->findSegment(SegKeySig, tick)) != 0) {
+                                    pKeySigElem = pKeySigSegm->element(staffIdx*VOICES);
+                                    if(pKeySigElem != 0 && !((KeySig*)pKeySigElem)->showCourtesySig())
+                                    bShowCourtesySig = false;
+                                    }
+
+                              if (key1 != key2 && bShowCourtesySig) {
                                     hasCourtesyKeysig = true;
                                     Segment* s  = m->getSegment(SegKeySigAnnounce, tick);
                                     int track = staffIdx * VOICES;
@@ -1425,7 +1437,7 @@ QList<System*> Score::layoutSystemRow(qreal x, qreal y, qreal rowWidth,
             foreach (MeasureBase* mb, system->measures()) {
                   if (mb->type() == HBOX)
                         minWidth += point(((Box*)mb)->boxWidth());
-                  else {
+                  else if(mb->type() == MEASURE) {
                         Measure* m = (Measure*)mb;
                         if (needRelayout)
                               m->layoutX(1.0);
