@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: menus.cpp 2992 2010-04-22 14:42:39Z lasconic $
+//  $Id: menus.cpp 3923 2011-01-19 14:54:58Z wschweer $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -401,15 +401,10 @@ void MuseScore::showPalette(bool visible)
             sp->setName(tr("Accidentals"));
             sp->setGrid(33, 36);
 
-            for (int i = 1; i < 6; ++i) {
+            for (int i = ACC_SHARP; i < ACC_END; ++i) {
                   Accidental* s = new Accidental(gscore);
                   s->setSubtype(i);
-                  sp->append(s, qApp->translate("accidental", s->subTypeName()));
-                  }
-            for (int i = 16; i < 26+9; ++i) {
-                  Accidental* s = new Accidental(gscore);
-                  s->setSubtype(i);
-                  sp->append(s, qApp->translate("accidental", s->subTypeName()));
+                  sp->append(s, qApp->translate("accidental", s->subtypeUserName()));
                   }
             AccidentalBracket* ab = new AccidentalBracket(gscore);
             ab->setSubtype(0);
@@ -927,22 +922,10 @@ void MuseScore::accidentalsMenu()
             accidentalsPalette->setWindowTitle(tr("MuseScore: Accidentals"));
             sp->setGrid(40, 50);
 
-#if 0
-            for (int i = 1; i < 16+6+4+9; ++i) {
+            for (int i = ACC_SHARP; i < ACC_END; ++i) {
                   Accidental* s = new Accidental(gscore);
                   s->setSubtype(i);
-                  sp->append(s, qApp->translate("accidental", s->subTypeName()));
-                  }
-#endif
-            for (int i = 1; i < 6; ++i) {
-                  Accidental* s = new Accidental(gscore);
-                  s->setSubtype(i);
-                  sp->append(s, qApp->translate("accidental", s->subTypeName()));
-                  }
-            for (int i = 16; i < 26+9; ++i) {
-                  Accidental* s = new Accidental(gscore);
-                  s->setSubtype(i);
-                  sp->append(s, qApp->translate("accidental", s->subTypeName()));
+                  sp->append(s, qApp->translate("accidental", s->subtypeUserName()));
                   }
             AccidentalBracket* ab = new AccidentalBracket(gscore);
             ab->setSubtype(0);
@@ -1044,6 +1027,7 @@ void MuseScore::fingeringMenu()
             for (unsigned i = 0; i < strlen(finger); ++i) {
                   k = new Text(gscore);
                   k->setSubtype(TEXT_FINGERING);
+                  k->setTextStyle(TEXT_STYLE_FINGERING);
                   k->setText(QString(finger[i]));
                   sp->append(k, tr("Fingering %1").arg(finger[i]));
                   }
@@ -1051,6 +1035,7 @@ void MuseScore::fingeringMenu()
             for (unsigned i = 0; i < strlen(stringnumber); ++i) {
                   Text* k = new Text(gscore);
                   k->setSubtype(TEXT_STRING_NUMBER);
+                  k->setTextStyle(TEXT_STYLE_STRING_NUMBER);
                   k->setText(QString(stringnumber[i]));
                   sp->append(k, tr("String number %1").arg(stringnumber[i]));
                   }
@@ -1078,7 +1063,7 @@ void Score::addTempo()
             _tempomap->addTempo(tick, bps);
             TempoText* tt = new TempoText(this);
             tt->setTick(tick);
-            tt->setTrack(cr->track());
+            tt->setTrack(0);
             tt->setText(editTempo->text());
             tt->setTempo(bps);
             tt->setParent(m);
