@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: note.cpp 3269 2010-07-09 20:20:39Z lasconic $
+//  $Id: note.cpp 3991 2011-02-03 16:43:35Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -557,9 +557,10 @@ void Note::write(Xml& xml, int /*startTick*/, int endTick) const
             xml.tag("tuning", _tuning);
 
       if (userAccidental())
-            xml.tag("userAccidental", userAccidental());
+            xml.tag("userAccidental", userAccidental() & 0x7fff);
       if (_accidental &&
-         (!_accidental->userOff().isNull() || !_accidental->visible())
+         (!_accidental->userOff().isNull() || !_accidental->visible()
+          || _accidental->hasBracket())
          ) {
             _accidental->write(xml);
             }
@@ -747,18 +748,24 @@ QRectF Note::drag(const QPointF& s)
 
 void Note::endDrag()
       {
+      dragMode     = false;
       if (_lineOffset == 0)
             return;
       setLine(_line + _lineOffset);
       _lineOffset  = 0;
-      dragMode     = false;
       int staffIdx = chord()->staffIdx() + chord()->staffMove();
       Staff* staff = score()->staff(staffIdx);
       int tick     = chord()->tick();
       int clef     = staff->clef(tick);
       int key      = staff->key(tick).accidentalType();
       int npitch   = line2pitch(_line, clef, key);
-      score()->undoChangePitch(this, npitch, pitch2tpc(npitch, key), 0);
+
+      Note* n = this;
+      while (n->tieBack())
+            n = n->tieBack()->startNote();
+      for (; n; n = n->tieFor() ? n->tieFor()->endNote() : 0)
+            score()->undoChangePitch(n, npitch, pitch2tpc(npitch, key), 0);
+
       score()->select(this, SELECT_SINGLE, 0);
       }
 
@@ -1156,17 +1163,17 @@ void Note::propertyAction(ScoreView* viewer, const QString& s)
                               score()->undoChangeUserMirror(note, DirectionH(vp.getUserMirror()));
                         if (vp.getHeadType() != note->headType() || vp.getHeadGroup() != note->headGroup())
                               score()->undo()->push(new ChangeNoteHead(note, vp.getHeadGroup(), vp.getHeadType()));
-                        }
-                  if (veloType() != vp.veloType() || velocity() != vp.velo()
-                     || veloOffset() != vp.veloOffset()
-                     || onTimeType() != vp.onTimeType() || onTimeOffset() != vp.onTimeOffset()
-                     || onTimeUserOffset() != vp.onTimeUserOffset()
-                     || offTimeType() != vp.offTimeType() || offTimeOffset() != vp.offTimeOffset()
-                     || offTimeUserOffset() != vp.offTimeUserOffset()) {
-                        score()->undo()->push(new ChangeNoteProperties(this,
-                           vp.veloType(), vp.velo(), vp.veloOffset(),
-                           vp.onTimeType(), vp.onTimeOffset(), vp.onTimeUserOffset(),
-                           vp.offTimeType(), vp.offTimeOffset(), vp.offTimeUserOffset()));
+                        if (note->veloType() != vp.veloType() || note->velocity() != vp.velo()
+                         || note->veloOffset() != vp.veloOffset()
+                         || note->onTimeType() != vp.onTimeType() || note->onTimeOffset() != vp.onTimeOffset()
+                         || note->onTimeUserOffset() != vp.onTimeUserOffset()
+                         || note->offTimeType() != vp.offTimeType() || note->offTimeOffset() != vp.offTimeOffset()
+                         || note->offTimeUserOffset() != vp.offTimeUserOffset()) {
+                              score()->undo()->push(new ChangeNoteProperties(note,
+                                 vp.veloType(), vp.velo(), vp.veloOffset(),
+                                 vp.onTimeType(), vp.onTimeOffset(), vp.onTimeUserOffset(),
+                                 vp.offTimeType(), vp.offTimeOffset(), vp.offTimeUserOffset()));
+                              }
                         }
                   }
             }
@@ -1231,7 +1238,9 @@ void Note::layout1(char* tversatz)
       if (acci != ACC_NONE && !_tieBack && !_hidden) {
             if (!_accidental)
                   add(new Accidental(score()));
-            _accidental->setSubtype(acci);
+            _accidental->setSubtype(acci & 0x7fff);
+            if (acci & 0x8000)
+                  _accidental->setHasBracket(true);
             }
       else {
             if (_accidental) {
