@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: sccursor.cpp 2890 2010-03-16 16:52:27Z lasconic $
+//  $Id: sccursor.cpp 3342 2010-08-04 20:31:21Z lasconic $
 //
 //  Copyright (C) 2009 Werner Schweer and others
 //
@@ -67,8 +67,8 @@ ChordRest* SCursor::cr() const
       if (_segment) {
             int track = _staffIdx * VOICES + _voice;
             Element* e = _segment->element(track);
-            if (e && e->isChordRest())
-                  return static_cast<ChordRest*>(e);
+            if (e && (e->isChordRest() || e->type() == REPEAT_MEASURE)) 
+                  return static_cast<ChordRest*>(e);  
             }
       return 0;
       }
@@ -389,8 +389,8 @@ bool SCursor::next()
             }
 
       if (_staffIdx >= 0) {
-            int track = _staffIdx * VOICES + _voice;
-            while (seg && (!(seg->subtype() & (SegChordRest | SegGrace)) || !seg->element(track))) {
+            //int track = _staffIdx * VOICES + _voice;
+            while (seg && (!(seg->subtype() & (SegChordRest | SegGrace)) /*|| !seg->element(track)*/)) {
                   seg = seg->next1();
                   }
             }
@@ -466,13 +466,31 @@ void SCursor::putStaffText(Text* s)
 void SCursor::add(ChordRest* c)
       {
       ChordRest* chordRest = cr();
+      int track       = _staffIdx * VOICES + _voice;
+      
       if (!chordRest) {
-            printf("SCursor::add: no cr\n");
-            return;
+            if(_voice > 0) { //create rests
+                int t = tick();
+                //trick : go to the start if we don't have segment nor chord.
+                if(t == _score->lastMeasure()->tick() + _score->lastMeasure()->tickLen())
+                      t = 0;
+                Measure* measure = score()->tick2measure(t);
+                SegmentType st = SegChordRest;
+                Segment* seg = measure->findSegment(st, t);
+                if (seg == 0) {
+                      seg = measure->createSegment(st, t);
+                      score()->undoAddElement(seg);
+                      }
+                chordRest = score()->addRest(seg, track, Duration(Duration::V_MEASURE), 0);
+                }
+            if (!chordRest) {
+                  printf("SCursor::add: no cr\n");    
+                  return;
+                  }
             }
       int tick = chordRest->tick();
       Fraction len(c->duration().fraction());
-      int track       = _staffIdx * VOICES + _voice;
+      
       Fraction gap    = score()->makeGap(chordRest, len, chordRest->tuplet());
       if (gap < len) {
             printf("cannot make gap\n");
