@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: score.cpp 3483 2010-09-21 09:05:37Z lasconic $
+//  $Id: score.cpp 3794 2010-12-22 22:38:11Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -278,10 +278,10 @@ Score::Score(const Style& s)
       _creditsRead    = false;
       _defaultsRead   = false;
       rights          = 0;
-      _pageOffset     = 0;
       _tempomap       = new AL::TempoMap;
       _sigmap         = new AL::TimeSigMap;
       _sigmap->add(0, Fraction(4, 4));
+      curTick = 0;
       connect(_undo, SIGNAL(cleanChanged(bool)), SLOT(setClean(bool)));
       }
 
@@ -403,6 +403,10 @@ bool Score::read(QString name)
                   if(!importOve(name))
             		        return false;
 				          }
+            else if (csl == "bww") {
+                  if (!importBww(name))
+                        return false;
+                  }
             else {
                   printf("unknown file suffix <%s>, name <%s>\n", qPrintable(cs), qPrintable(name));
                   return false;
