@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: score.h 3492 2010-09-22 09:08:45Z lasconic $
+//  $Id: score.h 3794 2010-12-22 22:38:11Z lasconic $
 //
 //  Copyright (C) 2002-2010 Werner Schweer and others
 //
@@ -372,7 +372,6 @@ class Score : public QObject {
       int curTrack;
 
       TextC* rights;                ///< Copyright printed at bottom of page
-      int _pageOffset;              ///< Offset for page numbers.
 
       void cmdAppendMeasures(int);
       void cmdInsertMeasures(int);
@@ -553,6 +552,7 @@ class Score : public QObject {
       bool importBB(const QString& name);
       bool importCapella(const QString& name);
       bool importOve(const QString& name);
+      bool importBww(const QString& name);
       void saveFile(QFileInfo& info, bool autosave);
       void saveFile(QIODevice* f, bool autosave);
       void saveCompressedFile(QFileInfo&, bool autosave);
