@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: scscore.cpp 3425 2010-08-28 14:58:38Z lasconic $
+//  $Id: scscore.cpp 3801 2010-12-23 12:12:27Z lasconic $
 //
 //  Copyright (C) 2009-2010 Werner Schweer and others
 //
@@ -46,14 +46,14 @@ static const char* const function_names_score[] = {
       "load", "save",
       "setExpandRepeat", "appendPart", "appendMeasures",
       "pages", "measures", "parts", "part", "startUndo", "endUndo", "setStyle", "hasLyrics", "hasHarmonies",
-      "staves", "keysig", "duration", "pageFormat"
+      "staves", "keysig", "duration", "pageFormat", "source"
       };
 static const int function_lengths_score[] = {
       1, 1, 1, 1,
       1, 6,
       1, 1, 1,
       0, 0, 0, 1, 0, 0, 2, 0, 0,
-      0, 0, 0, 0
+      0, 0, 0, 0, 1
       };
 
 static const QScriptValue::PropertyFlags flags_score[] = {
@@ -83,6 +83,7 @@ static const QScriptValue::PropertyFlags flags_score[] = {
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
       };
 
 ScriptInterface scoreInterface = {
@@ -407,6 +408,17 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                     return qScriptValueFromValue(context->engine(), score->pageFormat());
                   }
                   break;
+            case 22:   //source
+                  if (argc == 0) {           
+                        return qScriptValueFromValue(context->engine(), score->source());
+                        }
+                  else if (argc == 1) {
+                        QString s = qscriptvalue_cast<QString>(context->argument(0));
+                        if (s != 0)
+                              score->setSource(s);
+                        return context->engine()->undefinedValue();
+                  }
+                  break;
             }
       return context->throwError(QScriptContext::TypeError,
          QString::fromLatin1("Score.%0(): bad argument count or value")
