@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: seq.cpp 3343 2010-08-05 08:31:59Z lasconic $
+//  $Id: seq.cpp 3727 2010-11-24 15:48:07Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -68,6 +68,7 @@ Seq::Seq()
       running         = false;
       playlistChanged = false;
       cs              = 0;
+      cv              = 0;
 
       endTick  = 0;
       state    = STOP;
@@ -1102,8 +1103,21 @@ SeqMsgFifo::SeqMsgFifo()
 
 void SeqMsgFifo::enqueue(const SeqMsg& msg)
       {
-      if (isFull()) {
-            printf("SeqMsgFifo: overflow\n");
+      int i = 0;
+#ifdef __MINGW32__
+      int n = 500000;
+#else
+      int n = 50;
+#endif
+      for (; i < n; ++i) {
+            if (!isFull())
+                  break;
+#ifndef __MINGW32__
+            usleep(100000);
+#endif
+            }
+      if (i == n) {
+            printf("===SeqMsgFifo: overflow\n");
             return;
             }
       messages[widx] = msg;
