@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: system.cpp 3233 2010-06-28 12:54:32Z wschweer $
+//  $Id: system.cpp 3758 2010-12-13 14:52:53Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -464,11 +464,13 @@ void System::setInstrumentName(int staffIdx)
       if (isVbox())                 // ignore vbox
             return;
 
-      Staff* s   = score()->staff(staffIdx);
-      if (!s->isTop())
-            return;
-
+      Staff* s        = score()->staff(staffIdx);
       SysStaff* staff = _staves[staffIdx];
+      if (!s->isTop()) {
+            delete staff->instrumentName;
+            staff->instrumentName = 0;
+            return;
+            }
 
       //
       // instrument name can change after inserting/deleting parts
@@ -479,6 +481,7 @@ void System::setInstrumentName(int staffIdx)
       if (!iname) {
             Part* part = s->part();
             iname = new TextC(_firstSystem ? (*part->longName()) : (*part->shortName()));
+            iname->setSelectable(false);
             staff->instrumentName = iname;
             }
       else {
