@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: text.cpp 3355 2010-08-06 14:24:20Z wschweer $
+//  $Id: text.cpp 3606 2010-10-22 18:01:50Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -697,7 +697,10 @@ void TextB::layout()
 
 void TextB::draw(QPainter& p) const
       {
-      textBase()->draw(p, cursor);
+      if(score() && score()->printing())
+            textBase()->draw(p, 0);
+      else
+            textBase()->draw(p, cursor);
       }
 
 //---------------------------------------------------------
