@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: transposedialog.cpp 3270 2010-07-10 08:35:11Z lasconic $
+//  $Id: transposedialog.cpp 3832 2011-01-04 12:13:26Z lasconic $
 //
 //  Copyright (C) 2008-2010 Werner Schweer and others
 //
@@ -215,6 +215,8 @@ void Score::transpose()
       bool useDoubleSharpsFlats = td.useDoubleSharpsFlats();
       if (_selection.state() == SEL_LIST) {
             foreach(Element* e, _selection.elements()) {
+                  if (e->staff()->part()->useDrumset())
+                        continue;
                   if (e->type() == NOTE)
                         transpose(static_cast<Note*>(e), interval, useDoubleSharpsFlats);
                   else if ((e->type() == HARMONY) && transposeChordNames) {
@@ -228,7 +230,8 @@ void Score::transpose()
                         KeySigEvent key  = km->key(ks->tick());
                         KeySigEvent okey = km->key(ks->tick() - 1);
                         key.setNaturalType(okey.accidentalType());
-                        _undo->push(new ChangeKeySig(ks, key));
+                        _undo->push(new ChangeKeySig(ks, key, ks->showCourtesySig(),
+                             ks->showNaturals()));
                         }
                   }
             return;
@@ -242,6 +245,8 @@ void Score::transpose()
                   Element* e = segment->element(st);
                   if (!e || e->type() != CHORD)
                         continue;
+                  if (e->staff()->part()->useDrumset())
+                        continue;
                   Chord* chord = static_cast<Chord*>(e);
                   QList<Note*> nl = chord->notes();
                   foreach (Note* n, nl)
@@ -359,6 +364,8 @@ void Score::transposeKeys(int staffStart, int staffEnd, int tickStart, int tickE
 printf("transpose keys %d\n", semitones);
 
       for (int staffIdx = staffStart; staffIdx < staffEnd; ++staffIdx) {
+            if(part(staffIdx)->useDrumset())
+                  continue; 
             KeyList* km = staff(staffIdx)->keymap();
             for (iKeyList ke = km->lower_bound(tickStart);
                ke != km->lower_bound(tickEnd); ++ke) {
@@ -381,7 +388,8 @@ printf("transpose keys %d\n", semitones);
                         KeySigEvent key  = km->key(s->tick());
                         KeySigEvent okey = km->key(s->tick() - 1);
                         key.setNaturalType(okey.accidentalType());
-                        _undo->push(new ChangeKeySig(ks, key));
+                        _undo->push(new ChangeKeySig(ks, key, ks->showCourtesySig(),
+                              ks->showNaturals()));
                         }
                   }
             }
