@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: undo.cpp 3483 2010-09-21 09:05:37Z lasconic $
+//  $Id: undo.cpp 3832 2011-01-04 12:13:26Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -512,9 +512,33 @@ void Score::undoTransposeHarmony(Harmony* h, int rootTpc, int baseTpc)
 //   undoExchangeVoice
 //---------------------------------------------------------
 
-void Score::undoExchangeVoice(Measure* measure, int val1, int val2, int staff1, int staff2)
+void Score::undoExchangeVoice(Measure* measure, int v1, int v2, int staff1, int staff2)
       {
-      _undo->push(new ExchangeVoice(measure, val1, val2, staff1, staff2));
+      undo()->push(new ExchangeVoice(measure, v1, v2, staff1, staff2));
+      if (v1 == 0 || v2 == 0) {
+            for (int staffIdx = staff1; staffIdx < staff2; ++staffIdx) {
+                  // check for complete timeline of voice 0
+                  int ctick  = measure->tick();
+                  int track = staffIdx * VOICES;
+                  for (Segment* s = measure->first(SegChordRest); s; s = s->next(SegChordRest)) {
+                        ChordRest* cr = static_cast<ChordRest*>(s->element(track));
+                        if (cr == 0)
+                              continue;
+                        if (ctick < s->tick()) {
+                              // fill gap
+                              int ticks = s->tick() - ctick;
+                              setRest(ctick, track, Fraction::fromTicks(ticks), false, 0);
+                              }
+                        ctick = s->tick() + cr->ticks();
+                        }
+                  int etick = measure->tick() + measure->tickLen();
+                  if (ctick < etick) {
+                        // fill gap
+                        int ticks = etick - ctick;
+                        setRest(ctick, track, Fraction::fromTicks(ticks), false, 0);
+                        }
+                  }
+            }
       }
 
 //---------------------------------------------------------
@@ -1005,13 +1029,22 @@ void InsertMeasure::redo()
 SortStaves::SortStaves(Score* s, QList<int> l)
       {
       score = s;
+      
+      for(int i=0 ; i < l.size(); i++) {
+            rlist.append(l.indexOf(i));
+            }
       list  = l;
       }
 
-void SortStaves::flip()
+void SortStaves::redo()
       {
       score->sortStaves(list);
       }
+      
+void SortStaves::undo()
+      {
+      score->sortStaves(rlist);
+      }
 
 //---------------------------------------------------------
 //   ToggleInvisible
@@ -1318,10 +1351,12 @@ void ChangeKey::redo()
 //   ChangeKeySig
 //---------------------------------------------------------
 
-ChangeKeySig::ChangeKeySig(KeySig* _keysig, KeySigEvent _ks)
+ChangeKeySig::ChangeKeySig(KeySig* _keysig, KeySigEvent _ks, bool sc, bool sn)
       {
       keysig = _keysig;
       ks     = _ks;
+      showCourtesy = sc;
+      showNaturals = sn;
       }
 
 //---------------------------------------------------------
@@ -1331,8 +1366,16 @@ ChangeKeySig::ChangeKeySig(KeySig* _keysig, KeySigEvent _ks)
 void ChangeKeySig::flip()
       {
       KeySigEvent oe = keysig->keySigEvent();
+      bool sc        = keysig->showCourtesySig();
+      bool sn        = keysig->showNaturals();
+
       keysig->setSubtype(ks);
-      ks = oe;
+      keysig->setShowCourtesySig(showCourtesy);
+      keysig->setShowNaturals(showNaturals);
+
+      showCourtesy = sc;
+      showNaturals = sn;
+      ks           = oe;
       }
 
 //---------------------------------------------------------
@@ -2007,6 +2050,9 @@ void ChangePart::flip()
       shortName             = part->shortName()->swapDoc(shortName);
       instrument            = oi;
       part->score()->setInstrumentNames();
+      part->score()->rebuildMidiMapping();
+      seq->initInstruments();
+      part->score()->setPlaylistDirty(true);
       }
 
 //---------------------------------------------------------
